<?php
//
// ZoneMinder web Argentinian Spanish language file, $Date: 2011-05-25 10:15:14 +0100 (Wed, 25 May 2011) $, $Revision: 3364 $
// Copyright (C) 2001-2008 Philip Coombes
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//

// ZoneMinder Spanish 'Argentina' Translation by Fernando Diaz.

// Simple String Replacements
$SLANG = array(
    '24BitColour'          => 'Color 24 bits',
    '8BitGrey'             => 'Grises 8 bits',
    'Action'               => 'Action',
    'Actual'               => 'Actual',
    'AddNewControl'        => 'Add New Control',
    'AddNewMonitor'        => 'Agregar Nuevo Monitor',
    'AddNewUser'           => 'Agregar Nuevo Usuario',
    'AddNewZone'           => 'Agregar Nueva Zona',
    'Alarm'                => 'Alarma',
    'AlarmBrFrames'        => 'Alarma<br/>Cuadros',
    'AlarmFrame'           => 'Cuadro Alarma',
    'AlarmFrameCount'      => 'Alarm Frame Count',
    'AlarmLimits'          => 'Alarm Limits',
    'AlarmMaximumFPS'      => 'Alarm Maximum FPS',
    'AlarmPx'              => 'Alarm Px',
    'AlarmRGBUnset'        => 'You must set an alarm RGB colour',
    'Alert'                => 'Alerta',
    'All'                  => 'Todo',
    'Apply'                => 'Aplicar',
    'ApplyingStateChange'  => 'Aplicar Cambio Estado',
    'ArchArchived'         => 'Solo Archivados',
    'ArchUnarchived'       => 'Solo Sin Archivar',
    'Archive'              => 'Archivar',
    'Archived'             => 'Archived',
    'Area'                 => 'Area',
    'AreaUnits'            => 'Area (px/%)',
    'AttrAlarmFrames'      => 'Alarm Frames',
    'AttrArchiveStatus'    => 'Estado Archivo',
    'AttrAvgScore'         => 'Puntaje Prom.',
    'AttrCause'            => 'Cause',
    'AttrDate'             => 'Fecha',
    'AttrDateTime'         => 'Fecha/Hora',
    'AttrDiskBlocks'       => 'Disk Blocks',
    'AttrDiskPercent'      => 'Disk Percent',
    'AttrDuration'         => 'Duracin',
    'AttrFrames'           => 'Cuadros',
    'AttrId'               => 'Id',
    'AttrMaxScore'         => 'Puntaje Mximo',
    'AttrMonitorId'        => 'Monitor Id',
    'AttrMonitorName'      => 'Nombre Monitor',
    'AttrName'             => 'Name',
    'AttrNotes'            => 'Notes',
    'AttrSystemLoad'       => 'System Load',
    'AttrTime'             => 'Hora',
    'AttrTotalScore'       => 'Puntaje Total',
    'AttrWeekday'          => 'Da Semana',
    'Auto'                 => 'Auto',
    'AutoStopTimeout'      => 'Auto Stop Timeout',
    'Available'            => 'Available',              // Added - 2009-03-31
    'AvgBrScore'           => 'Punt.<br/>Promedio',
    'Background'           => 'Background',
    'BackgroundFilter'     => 'Run filter in background',
    'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
    'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
    'BadChannel'           => 'Channel must be set to an integer of zero or more',
    'BadDevice'            => 'Device must be set to a valid value',
    'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
    'BadFormat'            => 'Format must be set to an integer of zero or more',
    'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
    'BadHeight'            => 'Height must be set to a valid value',
    'BadHost'              => 'Host must be set to a valid ip address or hostname, do not include http://',
    'BadImageBufferCount'  => 'Image buffer size must be an integer of 10 or more',
    'BadLabelX'            => 'Label X co-ordinate must be set to an integer of zero or more',
    'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
    'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
    'BadNameChars'         => 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya',
    'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
    'BadPath'              => 'Path must be set to a valid value',
    'BadPort'              => 'Port must be set to a valid number',
    'BadPostEventCount'    => 'Post event image count must be an integer of zero or more',
    'BadPreEventCount'     => 'Pre event image count must be at least zero, and less than image buffer size',
    'BadRefBlendPerc'      => 'Reference blend percentage must be a positive integer',
    'BadSectionLength'     => 'Section length must be an integer of 30 or more',
    'BadSignalCheckColour' => 'Signal check colour must be a valid RGB colour string',
    'BadStreamReplayBuffer'=> 'Stream replay buffer must be an integer of zero or more',
    'BadWarmupCount'       => 'Warmup frames must be an integer of zero or more',
    'BadWebColour'         => 'Web colour must be a valid web colour string',
    'BadWidth'             => 'Width must be set to a valid value',
    'Bandwidth'            => 'Velocidad',
    'BlobPx'               => 'Blob Px',
    'BlobSizes'            => 'Blob Sizes',
    'Blobs'                => 'Blobs',
    'Brightness'           => 'Brillo',
    'Buffers'              => 'Buffers',
    'CanAutoFocus'         => 'Can Auto Focus',
    'CanAutoGain'          => 'Can Auto Gain',
    'CanAutoIris'          => 'Can Auto Iris',
    'CanAutoWhite'         => 'Can Auto White Bal.',
    'CanAutoZoom'          => 'Can Auto Zoom',
    'CanFocus'             => 'Can Focus',
    'CanFocusAbs'          => 'Can Focus Absolute',
    'CanFocusCon'          => 'Can Focus Continuous',
    'CanFocusRel'          => 'Can Focus Relative',
    'CanGain'              => 'Can Gain ',
    'CanGainAbs'           => 'Can Gain Absolute',
    'CanGainCon'           => 'Can Gain Continuous',
    'CanGainRel'           => 'Can Gain Relative',
    'CanIris'              => 'Can Iris',
    'CanIrisAbs'           => 'Can Iris Absolute',
    'CanIrisCon'           => 'Can Iris Continuous',
    'CanIrisRel'           => 'Can Iris Relative',
    'CanMove'              => 'Can Move',
    'CanMoveAbs'           => 'Can Move Absolute',
    'CanMoveCon'           => 'Can Move Continuous',
    'CanMoveDiag'          => 'Can Move Diagonally',
    'CanMoveMap'           => 'Can Move Mapped',
    'CanMoveRel'           => 'Can Move Relative',
    'CanPan'               => 'Can Pan' ,
    'CanReset'             => 'Can Reset',
    'CanSetPresets'        => 'Can Set Presets',
    'CanSleep'             => 'Can Sleep',
    'CanTilt'              => 'Can Tilt',
    'CanWake'              => 'Can Wake',
    'CanWhite'             => 'Can White Balance',
    'CanWhiteAbs'          => 'Can White Bal. Absolute',
    'CanWhiteBal'          => 'Can White Bal.',
    'CanWhiteCon'          => 'Can White Bal. Continuous',
    'CanWhiteRel'          => 'Can White Bal. Relative',
    'CanZoom'              => 'Can Zoom',
    'CanZoomAbs'           => 'Can Zoom Absolute',
    'CanZoomCon'           => 'Can Zoom Continuous',
    'CanZoomRel'           => 'Can Zoom Relative',
    'Cancel'               => 'Cancelar',
    'CancelForcedAlarm'    => 'Cancelar Alarma Forzada',
    'CaptureHeight'        => 'Captura Alto',
    'CaptureMethod'        => 'Capture Method',         // Added - 2009-02-08
    'CapturePalette'       => 'Captura Paleta',
    'CaptureWidth'         => 'Captura Ancho',
    'Cause'                => 'Cause',
    'CheckMethod'          => 'Alarm Check Method',
    'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
    'ChooseFilter'         => 'Elegir Filtro',
    'ChoosePreset'         => 'Choose Preset',
    'Close'                => 'Cerrar',
    'Colour'               => 'Color',
    'Command'              => 'Command',
    'Config'           => 'Config.',
    'ConfiguredFor'        => 'Configurado Para',
    'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
    'ConfirmPassword'      => 'Confirmar Contrasea',
    'ConjAnd'              => 'y',
    'ConjOr'               => 'o',
    'Console'              => 'Console', 
    'ContactAdmin'         => 'Contacte el Administrador para detalles.',
    'Continue'             => 'Continue',
    'Contrast'             => 'Contraste',
    'Control'              => 'Control',
    'ControlAddress'       => 'Control Address',
    'ControlCap'           => 'Control Capability',
    'ControlCaps'          => 'Control Capabilities',
    'ControlDevice'        => 'Control Device',
    'ControlType'          => 'Control Type',
    'Controllable'         => 'Controllable',
    'Cycle'                => 'Cycle',
    'CycleWatch'           => 'Cycle Watch',
    'Day'                  => 'Da',
    'Debug'                => 'Debug',
    'DefaultRate'          => 'Default Rate',
    'DefaultScale'         => 'Default Scale',
    'DefaultView'          => 'Default View',
    'Delete'               => 'Borrar',
    'DeleteAndNext'        => 'Borrar &amp; Prximo',
    'DeleteAndPrev'        => 'Borrar &amp; Anterior',
    'DeleteSavedFilter'    => 'Borrar Filtro Guardado',
    'Description'          => 'Descripcin',
    'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
    'Device'               => 'Device',                 // Added - 2009-02-08
    'DeviceChannel'        => 'Canal',
    'DeviceFormat'         => 'Seal',
    'DeviceNumber'         => 'Fuente',
    'DevicePath'           => 'Device Path',
    'Devices'              => 'Devices',
    'Dimensions'           => 'Dimensiones',
    'DisableAlarms'        => 'Disable Alarms',
    'Disk'                 => 'Disco',
    'Display'              => 'Display',                // Added - 2011-01-30
    'Donate'               => 'Please Donate',
    'DonateAlready'        => 'No, I\'ve already donated',
    'DonateEnticement'     => 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.',
    'DonateRemindDay'      => 'Not yet, remind again in 1 day',
    'DonateRemindHour'     => 'Not yet, remind again in 1 hour',
    'DonateRemindMonth'    => 'Not yet, remind again in 1 month',
    'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
    'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
    'DonateYes'            => 'Yes, I\'d like to donate now',
    'Download'             => 'Download',
    'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
    'Duration'             => 'Duracin',
    'Edit'                 => 'Editar',
    'Email'                => 'Email',
    'EnableAlarms'         => 'Enable Alarms',
    'Enabled'              => 'Habilitado',
    'EnterNewFilterName'   => 'Ingresar Nuevo Nombre De Filtro',
    'Error'                => 'Error',
    'ErrorBrackets'        => 'Error, Revisar si tiene la misma cantidad de parntesis de apertura',
    'ErrorValidValue'      => 'Error, Revisar si los trminos tienen nombres validos',
    'Etc'                  => 'etc',
    'Event'                => 'Evento',
    'EventFilter'          => 'Filtro de Evento',
    'EventId'              => 'Event Id',
    'EventName'            => 'Event Name',
    'EventPrefix'          => 'Event Prefix',
    'Events'               => 'Eventos',
    'Exclude'              => 'Excluir',
    'Execute'              => 'Execute',
    'Export'               => 'Export',
    'ExportDetails'        => 'Export Event Details',
    'ExportFailed'         => 'Export Failed',
    'ExportFormat'         => 'Export File Format',
    'ExportFormatTar'      => 'Tar',
    'ExportFormatZip'      => 'Zip',
    'ExportFrames'         => 'Export Frame Details',
    'ExportImageFiles'     => 'Export Image Files',
    'ExportMiscFiles'      => 'Export Other Files (if present)',
    'ExportOptions'        => 'Export Options',
    'ExportSucceeded'      => 'Export Succeeded',       // Added - 2009-02-08
    'ExportVideoFiles'     => 'Export Video Files (if present)',
    'Exporting'            => 'Exporting',
    'FPS'                  => 'fps',
    'FPSReportInterval'    => 'Intervalo de Reporte FPS',
    'FTP'                  => 'FTP',
    'Far'                  => 'Far',
    'FastForward'          => 'Fast Forward',
    'Feed'                 => 'Vista',
    'Ffmpeg'               => 'Ffmpeg',                 // Added - 2009-02-08
    'File'                 => 'File',
    'FilterArchiveEvents'  => 'Archivar todos los eventos',
    'FilterDeleteEvents'   => 'Borrar todos los eventos',
    'FilterEmailEvents'    => 'Mandar un mail de todos los eventos',
    'FilterExecuteEvents'  => 'Ejecutar un comando en las coincidencias',
    'FilterMessageEvents'  => 'Mandar un mensaje de los eventos',
    'FilterPx'             => 'Filtro Px',
    'FilterUnset'          => 'You must specify a filter width and height',
    'FilterUploadEvents'   => 'Subir los eventos que coincidan',
    'FilterVideoEvents'    => 'Create video for all matches',
    'Filters'              => 'Filters',
    'First'                => 'Primero',
    'FlippedHori'          => 'Flipped Horizontally',
    'FlippedVert'          => 'Flipped Vertically',
    'Focus'                => 'Focus',
    'ForceAlarm'           => 'Forzar Alarma',
    'Format'               => 'Format',
    'Frame'                => 'Cuadro',
    'FrameId'              => 'Id Cuadro',
    'FrameRate'            => 'Velocidad del video',
    'FrameSkip'            => 'Saltear Cuadro',
    'Frames'               => 'Cuadros',
    'Func'                 => 'Func',
    'Function'             => 'Funcin',
    'Gain'                 => 'Gain',
    'General'              => 'General',
    'GenerateVideo'        => 'Crear Video',
    'GeneratingVideo'      => 'Creando Video',
    'GoToZoneMinder'       => 'Ir a Zoneminder.com',
    'Grey'                 => 'Gris',
    'Group'                => 'Group',
    'Groups'               => 'Groups',
    'HasFocusSpeed'        => 'Has Focus Speed',
    'HasGainSpeed'         => 'Has Gain Speed',
    'HasHomePreset'        => 'Has Home Preset',
    'HasIrisSpeed'         => 'Has Iris Speed',
    'HasPanSpeed'          => 'Has Pan Speed',
    'HasPresets'           => 'Has Presets',
    'HasTiltSpeed'         => 'Has Tilt Speed',
    'HasTurboPan'          => 'Has Turbo Pan',
    'HasTurboTilt'         => 'Has Turbo Tilt',
    'HasWhiteSpeed'        => 'Has White Bal. Speed',
    'HasZoomSpeed'         => 'Has Zoom Speed',
    'High'                 => 'Alta',
    'HighBW'               => 'Alta&nbsp;B/W',
    'Home'                 => 'Home',
    'Hour'                 => 'Hora',
    'Hue'                  => 'Saturacin',
    'Id'                   => 'Id',
    'Idle'                 => 'Pasivo',
    'Ignore'               => 'Ignorar',
    'Image'                => 'Imagen',
    'ImageBufferSize'      => 'Tamao del Buffer de Imagen',
    'Images'               => 'Images',
    'In'                   => 'In',
    'Include'              => 'Incluir',
    'Inverted'             => 'Invertido',
    'Iris'                 => 'Iris',
    'KeyString'            => 'Key String',
    'Label'                => 'Label',
    'Language'             => 'Lenguaje',
    'Last'                 => 'Ultimo',
    'Layout'               => 'Layout',                 // Added - 2009-02-08
    'LimitResultsPost'     => 'Resultados;', // This is used at the end of the phrase 'Limit to first N results only'
    'LimitResultsPre'      => 'Solo los primeros', // This is used at the beginning of the phrase 'Limit to first N results only'
    'LinkedMonitors'       => 'Linked Monitors',
    'List'                 => 'List',
    'Load'                 => 'Carga',
    'Local'                => 'Local',
    'LoggedInAs'           => 'Registrado Como',
    'LoggingIn'            => 'Ingresando',
    'Login'                => 'Ingresar',
    'Logout'               => 'Salir',
    'Low'                  => 'Baja',
    'LowBW'                => 'Baja&nbsp;B/W',
    'Main'                 => 'Main',
    'Man'                  => 'Man',
    'Manual'               => 'Manual',
    'Mark'                 => 'Marca',
    'Max'                  => 'Max',
    'MaxBandwidth'         => 'Max Bandwidth',
    'MaxBrScore'           => 'Puntaje<br/>Max.',
    'MaxFocusRange'        => 'Max Focus Range',
    'MaxFocusSpeed'        => 'Max Focus Speed',
    'MaxFocusStep'         => 'Max Focus Step',
    'MaxGainRange'         => 'Max Gain Range',
    'MaxGainSpeed'         => 'Max Gain Speed',
    'MaxGainStep'          => 'Max Gain Step',
    'MaxIrisRange'         => 'Max Iris Range',
    'MaxIrisSpeed'         => 'Max Iris Speed',
    'MaxIrisStep'          => 'Max Iris Step',
    'MaxPanRange'          => 'Max Pan Range',
    'MaxPanSpeed'          => 'Max Pan Speed',
    'MaxPanStep'           => 'Max Pan Step',
    'MaxTiltRange'         => 'Max Tilt Range',
    'MaxTiltSpeed'         => 'Max Tilt Speed',
    'MaxTiltStep'          => 'Max Tilt Step',
    'MaxWhiteRange'        => 'Max White Bal. Range',
    'MaxWhiteSpeed'        => 'Max White Bal. Speed',
    'MaxWhiteStep'         => 'Max White Bal. Step',
    'MaxZoomRange'         => 'Max Zoom Range',
    'MaxZoomSpeed'         => 'Max Zoom Speed',
    'MaxZoomStep'          => 'Max Zoom Step',
    'MaximumFPS'           => 'Maximos FPS',
    'Medium'               => 'Media',
    'MediumBW'             => 'Media&nbsp;B/W',
    'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
    'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
    'MinBlobAreaLtMax'     => 'Minimum blob area should be less than maximum',
    'MinBlobAreaUnset'     => 'You must specify the minimum blob pixel count',
    'MinBlobLtMinFilter'   => 'Minimum blob area should be less than or equal to minimum filter area',
    'MinBlobsLtMax'        => 'Minimum blobs should be less than maximum',
    'MinBlobsUnset'        => 'You must specify the minimum blob count',
    'MinFilterAreaLtMax'   => 'Minimum filter area should be less than maximum',
    'MinFilterAreaUnset'   => 'You must specify the minimum filter pixel count',
    'MinFilterLtMinAlarm'  => 'Minimum filter area should be less than or equal to minimum alarm area',
    'MinFocusRange'        => 'Min Focus Range',
    'MinFocusSpeed'        => 'Min Focus Speed',
    'MinFocusStep'         => 'Min Focus Step',
    'MinGainRange'         => 'Min Gain Range',
    'MinGainSpeed'         => 'Min Gain Speed',
    'MinGainStep'          => 'Min Gain Step',
    'MinIrisRange'         => 'Min Iris Range',
    'MinIrisSpeed'         => 'Min Iris Speed',
    'MinIrisStep'          => 'Min Iris Step',
    'MinPanRange'          => 'Min Pan Range',
    'MinPanSpeed'          => 'Min Pan Speed',
    'MinPanStep'           => 'Min Pan Step',
    'MinPixelThresLtMax'   => 'Minimum pixel threshold should be less than maximum',
    'MinPixelThresUnset'   => 'You must specify a minimum pixel threshold',
    'MinTiltRange'         => 'Min Tilt Range',
    'MinTiltSpeed'         => 'Min Tilt Speed',
    'MinTiltStep'          => 'Min Tilt Step',
    'MinWhiteRange'        => 'Min White Bal. Range',
    'MinWhiteSpeed'        => 'Min White Bal. Speed',
    'MinWhiteStep'         => 'Min White Bal. Step',
    'MinZoomRange'         => 'Min Zoom Range',
    'MinZoomSpeed'         => 'Min Zoom Speed',
    'MinZoomStep'          => 'Min Zoom Step',
    'Misc'                 => 'Otros',
    'Monitor'              => 'Monitor',
    'MonitorIds'           => 'Ids&nbsp;Monitor',
    'MonitorPreset'        => 'Monitor Preset',
    'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
    'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
    'Monitors'             => 'Monitores',
    'Montage'              => 'Cmara Mltiple',
    'Month'                => 'Mes',
    'Move'                 => 'Move',
    'MustBeGe'             => 'Debe ser mayor o igual que',
    'MustBeLe'             => 'Debe ser menor o igual que',
    'MustConfirmPassword'  => 'Debe confirmar la contrasea',
    'MustSupplyPassword'   => 'Debe ingresar una contrasea',
    'MustSupplyUsername'   => 'You must supply a username', // Added - 2009-02-08
    'Name'                 => 'Nombre',
    'Near'                 => 'Near',
    'Network'              => 'Red',
    'New'                  => 'Nuevo',
    'NewGroup'             => 'New Group',
    'NewLabel'             => 'New Label',
    'NewPassword'          => 'Nueva Contrasea',
    'NewState'             => 'Nuevo Estado',
    'NewUser'              => 'Nuevo Usuario',
    'Next'                 => 'Siguiente',
    'No'                   => 'No',
    'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
    'NoFramesRecorded'     => 'No hay movimientos grabados para este evento',
    'NoGroup'              => 'No Group',
    'NoSavedFilters'       => 'FiltrosNoGuardados',
    'NoStatisticsRecorded' => 'No hay estadisticas guardadas para este evento/marco',
    'None'                 => 'Ninguno',
    'NoneAvailable'        => 'Ninguno Disponible',
    'Normal'               => 'Normal',
    'Notes'                => 'Notes',
    'NumPresets'           => 'Num Presets',
    'Off'                  => 'Off',
    'On'                   => 'On',
    'OpEq'                 => 'igual que',
    'OpGt'                 => 'mayor que',
    'OpGtEq'               => 'mayor o igual que',
    'OpIn'                 => 'En sistema',
    'OpLt'                 => 'menor que',
    'OpLtEq'               => 'menor o igual que',
    'OpMatches'            => 'Coincide',
    'OpNe'                 => 'distinto que',
    'OpNotIn'              => 'No en sistema',
    'OpNotMatches'         => 'No coincide',
    'Open'                 => 'Open',
    'OptionHelp'           => 'Ayuda',
    'OptionRestartWarning' => 'Estos cambios no se guardaran completamente\nmientras el sistema se ejecute. Cuando termine\nde realizar los cambios asegurese de\nreiniciar Zoneminder.',
    'Options'              => 'Opciones',
    'OrEnterNewName'       => 'o agregue  nombre',
    'Order'                => 'Order',
    'Orientation'          => 'Orientacin',
    'Out'                  => 'Out',
    'OverwriteExisting'    => 'Sobreescribir Exitente',
    'Paged'                => 'Paged',
    'Pan'                  => 'Pan',
    'PanLeft'              => 'Pan Left',
    'PanRight'             => 'Pan Right',
    'PanTilt'              => 'Pan/Tilt',
    'Parameter'            => 'Parametro',
    'Password'             => 'Contrasea',
    'PasswordsDifferent'   => 'Las contraseas nueva y de confirmacion son diferentes',
    'Paths'                => 'Enlaces',
    'Pause'                => 'Pause',
    'Phone'                => 'Phone',
    'PhoneBW'              => 'Tel.&nbsp;B/N',
    'PixelDiff'            => 'Pixel Diff',             // Added - 2009-02-08
    'Pixels'               => 'pixels',
    'Play'                 => 'Play',
    'PlayAll'              => 'Play All',
    'PleaseWait'           => 'Espere por favor',
    'Point'                => 'Point',
    'PostEventImageBuffer' => 'Buffer Imagenes despues evento',
    'PreEventImageBuffer'  => 'Buffer Imagenes antes evento',
    'PreserveAspect'       => 'Preserve Aspect Ratio',
    'Preset'               => 'Preset',
    'Presets'              => 'Presets',
    'Prev'                 => 'Prev',
    'Probe'                => 'Probe',                  // Added - 2009-03-31
    'Protocol'             => 'Protocol',
    'Rate'                 => 'Ritmo',
    'Real'                 => 'Real',
    'Record'               => 'Registro',
    'RefImageBlendPct'     => 'Reference Image Blend %ge',
    'Refresh'              => 'Actualizar',
    'Remote'               => 'Remote',
    'RemoteHostName'       => 'Nombre Servidor Remoto',
    'RemoteHostPath'       => 'Enlace Servidor Remoto',
    'RemoteHostPort'       => 'Puerto Servidor Remoto',
    'RemoteHostSubPath'    => 'Remote Host SubPath',    // Added - 2009-02-08
    'RemoteImageColours'   => 'Remote Image Colours',
    'RemoteMethod'         => 'Remote Method',          // Added - 2009-02-08
    'RemoteProtocol'       => 'Remote Protocol',        // Added - 2009-02-08
    'Rename'               => 'Renombrar',
    'Replay'               => 'Replay',
    'ReplayAll'            => 'All Events',
    'ReplayGapless'        => 'Gapless Events',
    'ReplaySingle'         => 'Single Event',
    'Reset'                => 'Reset',
    'ResetEventCounts'     => 'Borrar Contador Eventos',
    'Restart'              => 'Reiniciar',
    'Restarting'           => 'Reiniciando',
    'RestrictedCameraIds'  => 'Id. Camara restringida',
    'RestrictedMonitors'   => 'Restricted Monitors',
    'ReturnDelay'          => 'Return Delay',
    'ReturnLocation'       => 'Return Location',
    'Rewind'               => 'Rewind',
    'RotateLeft'           => 'Rotar a la derecha',
    'RotateRight'          => 'Rotar a la izquierda',
    'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
    'RunMode'              => 'Metodo Ejecucion',
    'RunState'             => 'Estado de Ejecucin',
    'Running'              => 'Ejecutando',
    'Save'                 => 'Guardar',
    'SaveAs'               => 'Guardar Como',
    'SaveFilter'           => 'Guardar Filtro',
    'Scale'                => 'Escala',
    'Score'                => 'Res.',
    'Secs'                 => 'Seg',
    'Sectionlength'        => 'Longitud Seccin',
    'Select'               => 'Select',
    'SelectMonitors'       => 'Select Monitors',
    'SelfIntersecting'     => 'Polygon edges must not intersect',
    'Set'                  => 'Set',
    'SetNewBandwidth'      => 'Nuevo Ancho de Banda',
    'SetPreset'            => 'Set Preset',
    'Settings'             => 'Configuracion',
    'ShowFilterWindow'     => 'Abrir Filtro',
    'ShowTimeline'         => 'Show Timeline',
    'SignalCheckColour'    => 'Signal Check Colour',
    'Size'                 => 'Size',
    'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
    'Sleep'                => 'Sleep',
    'SortAsc'              => 'Asc',
    'SortBy'               => 'Ordenar por',
    'SortDesc'             => 'Desc',
    'Source'               => 'Origen',
    'SourceColours'        => 'Source Colours',         // Added - 2009-02-08
    'SourcePath'           => 'Source Path',            // Added - 2009-02-08
    'SourceType'           => 'Tipo Origen',
    'Speed'                => 'Speed',
    'SpeedHigh'            => 'High Speed',
    'SpeedLow'             => 'Low Speed',
    'SpeedMedium'          => 'Medium Speed',
    'SpeedTurbo'           => 'Turbo Speed',
    'Start'                => 'Iniciar',
    'State'                => 'Estado',
    'Stats'                => 'Est.',
    'Status'               => 'Estado',
    'Step'                 => 'Step',
    'StepBack'             => 'Step Back',
    'StepForward'          => 'Step Forward',
    'StepLarge'            => 'Large Step',
    'StepMedium'           => 'Medium Step',
    'StepNone'             => 'No Step',
    'StepSmall'            => 'Small Step',
    'Stills'               => 'Fotos',
    'Stop'                 => 'Desactivar',
    'Stopped'              => 'Apagado',
    'Stream'               => 'Stream',
    'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
    'Submit'               => 'Submit',
    'System'               => 'Sistema',
    'Tele'                 => 'Tele',
    'Thumbnail'            => 'Thumbnail',
    'Tilt'                 => 'Tilt',
    'Time'                 => 'Hora',
    'TimeDelta'            => 'Hora Delta',
    'TimeStamp'            => 'Etiqueta Hora',
    'Timeline'             => 'Timeline',
    'Timestamp'            => 'Etiqueta Hora',
    'TimestampLabelFormat' => 'Formato Etiqueta Hora',
    'TimestampLabelX'      => 'Eje X Etiqueta Hora',
    'TimestampLabelY'      => 'Eje Y Etiqueta Hora',
    'Today'                => 'Today',
    'Tools'                => 'Herra.',
    'TotalBrScore'         => 'Total<br/>puntuacin',
    'TrackDelay'           => 'Track Delay',
    'TrackMotion'          => 'Track Motion',
    'Triggers'             => 'Gatillos',
    'TurboPanSpeed'        => 'Turbo Pan Speed',
    'TurboTiltSpeed'       => 'Turbo Tilt Speed',
    'Type'                 => 'Tipo',
    'Unarchive'            => 'Desarchivar',
    'Undefined'            => 'Undefined',              // Added - 2009-02-08
    'Units'                => 'Unidades',
    'Unknown'              => 'Desconocido',
    'Update'               => 'Update',
    'UpdateAvailable'      => 'Una Actualizacin a ZoneMinder esta disponible',
    'UpdateNotNecessary'   => 'No se requiere Actualizacin',
    'UseFilter'            => 'Usar Filtro',
    'UseFilterExprsPost'   => '&nbsp;filtrar&nbsp;sentencias', // This is used at the end of the phrase 'use N filter expressions'
    'UseFilterExprsPre'    => 'Utilizar&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
    'User'                 => 'Usuario',
    'Username'             => 'Nombre',
    'Users'                => 'Usuarios',
    'Value'                => 'Valor',
    'Version'              => 'Versin',
    'VersionIgnore'        => 'Ignore esta versin',
    'VersionRemindDay'     => 'Recordar en 1 da',
    'VersionRemindHour'    => 'Recordar en 1 hora',
    'VersionRemindNever'   => 'No avizar de nuevas versiones',
    'VersionRemindWeek'    => 'Recordar en 1 semana',
    'Video'                => 'Video',
    'VideoFormat'          => 'Video Format',
    'VideoGenFailed'       => 'Fallo la creacion del video!',
    'VideoGenFiles'        => 'Existing Video Files',
    'VideoGenNoFiles'      => 'No Video Files Found',
    'VideoGenParms'        => 'Parametros Generacion Video',
    'VideoGenSucceeded'    => 'Video Generation Succeeded!',
    'VideoSize'            => 'Tamao Video',
    'View'                 => 'Ver',
    'ViewAll'              => 'Ver Todo',
    'ViewEvent'            => 'View Event',
    'ViewPaged'            => 'View Paged',
    'Wake'                 => 'Wake',
    'WarmupFrames'         => 'Avisos Movimiento',
    'Watch'                => 'Monitor',
    'Web'                  => 'Web',
    'WebColour'            => 'Web Colour',
    'Week'                 => 'Semana',
    'White'                => 'White',
    'WhiteBalance'         => 'White Balance',
    'Wide'                 => 'Wide',
    'X'                    => 'X',
    'X10'                  => 'X10',
    'X10ActivationString'  => 'X10 Comando Activacin',
    'X10InputAlarmString'  => 'X10 Comando Entrada Alarma',
    'X10OutputAlarmString' => 'X10 Output Alarm String',
    'Y'                    => 'Y',
    'Yes'                  => 'Si',
    'YouNoPerms'           => 'No tiene permisos para acceder a este recurso.',
    'Zone'                 => 'Zona',
    'ZoneAlarmColour'      => 'Color Alarma (Red/Green/Blue)',
    'ZoneArea'             => 'Zone Area',
    'ZoneFilterSize'       => 'Filter Width/Height (pixels)',
    'ZoneMinMaxAlarmArea'  => 'Min/Max Alarmed Area',
    'ZoneMinMaxBlobArea'   => 'Min/Max Blob Area',
    'ZoneMinMaxBlobs'      => 'Min/Max Blobs',
    'ZoneMinMaxFiltArea'   => 'Min/Max Filtered Area',
    'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
    'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
    'Zones'                => 'Zonas',
    'Zoom'                 => 'Zoom',
    'ZoomIn'               => 'Zoom In',
    'ZoomOut'              => 'Zoom Out',
);

// Complex replacements with formatting and/or placements, must be passed through sprintf
$CLANG = array(
    'CurrentLogin'         => 'Usuario actual es \'%1$s\'',
    'EventCount'           => '%1$s %2$s',
    'LastEvents'           => 'Ultimo %1$s %2$s',
    'LatestRelease'        => 'The latest release is v%1$s, you have v%2$s.',
    'MonitorCount'         => '%1$s %2$s',
    'MonitorFunction'      => 'Monitor %1$s Funcion',
    'RunningRecentVer'     => 'You are running the most recent version of Zoneminder, v%s.',
    'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
);

// Variable arrays expressing plurality, see the zmVlang description above
$VLANG = array(
    'Event'                => array( 0=>'Eventos', 1=>'Evento', 2=>'Eventos' ),
    'Monitor'              => array( 0=>'Monitores', 1=>'Monitor', 2=>'Monitores' ),
);

function zmVlang( $langVarArray, $count )
{
    krsort( $langVarArray );
    foreach ( $langVarArray as $key=>$value )
    {
        if ( abs($count) >= $key )
        {
            return( $value );
        }
    }
    die( 'Error, unable to correlate variable language string' );
}

$OLANG = array(
);

?>
